.. toctree::
    :maxdepth: 6

margarine Functions
--------------------

.. automodule:: margarine.maf
    :members:
    :special-members: __call__

.. automodule:: margarine.kde
    :members:
    :special-members: __call__

.. automodule:: margarine.clustered
    :members:
    :special-members: __call__

.. automodule:: margarine.marginal_stats
    :members:

